#vider tout
rm(list=ls())

#brancher les packages
library(xlsx) #lecture directe des fichiers EXCEL

#0. charger les donnes
donnees <- read.xlsx(file="etude_ronflement.xlsx",header=T,sheetIndex=1)

#liste des variables
str(donnees)

#rsum des variables
print(summary(donnees))

#1. rgression sur l'ensemble des variables
modele <- glm(RONFLE ~ ., data = donnees, family = binomial)
res.modele <- summary(modele)
print(res.modele)

#voir !!!
print(attributes(res.modele))

#2. rgression sans poids
modele2 <- glm(RONFLE ~ AGE+TAILLE+ALCOOL+SEXE+TABAC, data = donnees, family = binomial)
res.modele2 <- summary(modele2)
print(res.modele2)

#test du rapport de vraisemblance
LR <- res.modele2$deviance - res.modele$deviance
DF <- res.modele2$df.residual - res.modele$df.residual #DF <- 1 (parce que une variable retire)
PValue <- pchisq(LR,DF,lower.tail=F)
print(LR); print(DF); print(PValue)

#3. rgression sans poids et taille
modele3 <- glm(RONFLE ~ AGE+ALCOOL+SEXE+TABAC, data = donnees, family = binomial)
res.modele3 <- summary(modele3)

#test du rapport de vraisemblance
LR <- res.modele3$deviance - res.modele$deviance
DF <- res.modele3$df.residual - res.modele$df.residual #DF <- 2
PValue <- pchisq(LR,DF,lower.tail=F)
print(LR); print(DF); print(PValue)

#4. test SEXE pris isolment
print(summary(glm(RONFLE ~ SEXE, data = donnees, family=binomial)))

#5. boire ou ne pas boire, telle est la question
alcool.bin <- ifelse(donnees$ALCOOL > 0, 1, 0)
print(summary(glm(donnees$RONFLE ~ alcool.bin, family=binomial)))

#6. interaction alcool x tabac
print(summary(glm(RONFLE ~ TABAC+alcool.bin+TABAC*alcool.bin,data=donnees,family=binomial)))

#on aurait pu faire (R se charge d'introduire les interactions d'ordre infrieur)
print(summary(glm(RONFLE ~ TABAC*alcool.bin,data=donnees,family=binomial)))

#7. meta-niveau alcool
#niv0 sont ceux qui boivent pas
niv1 <- ifelse(donnees$ALCOOL >= 1, 1, 0)
niv2 <- ifelse(donnees$ALCOOL >= 6, 1, 0)
niv3 <- ifelse(donnees$ALCOOL >= 11, 1, 0)

print(summary(glm(donnees$RONFLE ~ niv1+niv2+niv3,family=binomial)))

#8.a.b AGE et ALCOOL
modele8 <- summary(glm(RONFLE ~ AGE+ALCOOL,data=donnees,family=binomial))
print(modele8)

#khi2
khi2 <- modele8$null.deviance - modele8$deviance
print(khi2)

#ddl
ddl <- modele8$df.null - modele8$df.residual
print(ddl)

#p-value
pvalue <- pchisq(khi2,ddl,lower.tail=FALSE)
print(pvalue)

#8.c interaction age * alcool
print(summary(glm(RONFLE ~ AGE+ALCOOL+AGE*ALCOOL,data=donnees,family=binomial)))
